| Package: |
| mvGST |
| Type: |
| Package |
| Version: |
| 0.99.3 |
| Date: |
| 2014-10-02 |
| License: |
| GPL-3 |
profileTable is a matrix with significance profiles for row names and contrasts tested (not including var(1)) for column names and the total number of gene sets that fit each profile for each contrast in the cells.pickOut returns the Gene Ontology ID's for the gene sets in a given cell of the results.table produced by profileTable.
graphCell uses the gene sets from pickOut to make a GO graph and displays the names of the gene sets in a legend.
go2Profile returns a matrix similar to the results.table for each desired gene set. The only difference is that there is only one gene set included in these matrices.
Mecham, D. S. (2014) "mvGST: Multivariate and Directional Gene Set Testing". MS Project, Utah State University, Department of Mathematics and Statistics. http://digitalcommons.usu.edu/gradreports/382/
Saunders, G., 2014. "Family-wise error rate control in QTL mapping and gene ontology graphs with remarks on family selection." PhD thesis, Utah State University, Department of Mathematics and Statistics. http://digitalcommons.usu.edu/etd/2164/
# See examples in help files of four main functions:
# ?profileTable; ?pickOut; ?go2Profile; ?graphCell
# See package vignette for larger examples with discussion:
# vignette("mvGST")
Run the code above in your browser using DataLab