mvGST (graphCell, profileTable, go2GeneSets, pickOut, and p.adjust.SFL):
changeTO10 |
| changes p-values in matrix to -1, 0, or 1, indicating significance. |
combinePvalues |
| Uses Stouffer's method to combine p-values in gene sets |
convertPvalues |
| converts p-values from one-sided to two-sided and vice versa |
cut |
| cuts out any all 0 rows from the matrix of results |
fillInList |
| fills in list of gene sets, ensuring that any gene in a child set is also in the parent set |
finalResults |
counts the number of gene sets corresponding to each profile and contrast and creates results.table |
geneNameConvertRows |
| handles one-to-many and many-to-one problems of gene name translation |
generateGeneSets |
| creates list of gene sets |
go2GeneSet |
| creates a single matrix showing which profile a gene set fits into for each contrast tested |
hartung |
| Combines a set of p-values using Hartung's modified inverse normal method |
interactiveGraph |
| Creates a GO Graph of selected GO terms |
method2 |
| Uses Hartung's method to combine p-values and handles many-to-one problem of gene name translation |
method3 |
| Handles one-to-many problem of gene name translation by eliminating all but one of the many |
method4 |
Combines method2 and method3 |
mvGSTObject |
| Creates an mvGST object |
mvSort |
Sorts results.table by row totals |
oneSideBYAdjust |
| Convert p-values to two-sided, then uses Benjamini-Yekutieli adjustment, and converts back to one-sided |
print.mvGST |
prints the results.table in a clean way |
print.summary.mvGST |
| prints the summary of an mvGST object |
profileCombine |
| Determines profiles of each gene set at each contrast |
profiles |
| Defines the possible profiles |
separate |
| splits genes (and their p-values) into gene sets |
summary.mvGST |
| creates a summary of an mvGST object |
tableColumns |
Creates the column names for the results.table |
distributeWeight |
| helper function for p.adjust.SFL |
getCurrentChildren |
| helper function for p.adjust.SFL |
makeCoherent |
| helper function for p.adjust.SFL |
getAncestorsAndOffspring |
| helper function for p.adjust.SFL |
turnListAround |
| From globaltest package, helper function for p.adjust.SFL |
vignette("mvGST")
Mecham, D. S. (2014) "mvGST: Multivariate and Directional Gene Set Testing". MS Project, Utah State University, Department of Mathematics and Statistics. http://digitalcommons.usu.edu/gradreports/382/
Saunders, G., 2014. "Family-wise error rate control in QTL mapping and gene ontology graphs with remarks on family selection." PhD thesis, Utah State University, Department of Mathematics and Statistics. http://digitalcommons.usu.edu/etd/2164/